# gmux (Python package)

A thin wrapper around the Rust-powered `gmux` binary.  Installing this package via `pip` gives you
the same terminal UI to jump between Git working directories and launch editors.

This distribution bundles the prebuilt macOS arm64 binary.
